@@ -25,7 +25,7 @@ Usage::
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_networkmanager.type_defs import (
     DescribeGlobalNetworksResponseTypeDef,
@@ -52,20 +52,20 @@ __all__ = (
 
 class DescribeGlobalNetworksPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeGlobalNetworks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+    [Paginator.DescribeGlobalNetworks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
     """
 
     def paginate(
         self, GlobalNetworkIds: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeGlobalNetworksResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeGlobalNetworksResponseTypeDef]:
         """
-        [DescribeGlobalNetworks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks.paginate)
+        [DescribeGlobalNetworks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks.paginate)
         """
 
 
 class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
     """
-    [Paginator.GetCustomerGatewayAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+    [Paginator.GetCustomerGatewayAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
     """
 
     def paginate(
@@ -73,15 +73,15 @@ class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         CustomerGatewayArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetCustomerGatewayAssociationsResponseTypeDef, None, None]:
+    ) -> Iterator[GetCustomerGatewayAssociationsResponseTypeDef]:
         """
-        [GetCustomerGatewayAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations.paginate)
+        [GetCustomerGatewayAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations.paginate)
         """
 
 
 class GetDevicesPaginator(Boto3Paginator):
     """
-    [Paginator.GetDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+    [Paginator.GetDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
     """
 
     def paginate(
@@ -90,15 +90,15 @@ class GetDevicesPaginator(Boto3Paginator):
         DeviceIds: List[str] = None,
         SiteId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetDevicesResponseTypeDef, None, None]:
+    ) -> Iterator[GetDevicesResponseTypeDef]:
         """
-        [GetDevices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices.paginate)
+        [GetDevices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices.paginate)
         """
 
 
 class GetLinkAssociationsPaginator(Boto3Paginator):
     """
-    [Paginator.GetLinkAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+    [Paginator.GetLinkAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
     """
 
     def paginate(
@@ -107,15 +107,15 @@ class GetLinkAssociationsPaginator(Boto3Paginator):
         DeviceId: str = None,
         LinkId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetLinkAssociationsResponseTypeDef, None, None]:
+    ) -> Iterator[GetLinkAssociationsResponseTypeDef]:
         """
-        [GetLinkAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations.paginate)
+        [GetLinkAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations.paginate)
         """
 
 
 class GetLinksPaginator(Boto3Paginator):
     """
-    [Paginator.GetLinks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+    [Paginator.GetLinks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
     """
 
     def paginate(
@@ -126,15 +126,15 @@ class GetLinksPaginator(Boto3Paginator):
         Type: str = None,
         Provider: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetLinksResponseTypeDef, None, None]:
+    ) -> Iterator[GetLinksResponseTypeDef]:
         """
-        [GetLinks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks.paginate)
+        [GetLinks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks.paginate)
         """
 
 
 class GetSitesPaginator(Boto3Paginator):
     """
-    [Paginator.GetSites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+    [Paginator.GetSites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
     """
 
     def paginate(
@@ -142,15 +142,15 @@ class GetSitesPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         SiteIds: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetSitesResponseTypeDef, None, None]:
+    ) -> Iterator[GetSitesResponseTypeDef]:
         """
-        [GetSites.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites.paginate)
+        [GetSites.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites.paginate)
         """
 
 
 class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
     """
-    [Paginator.GetTransitGatewayRegistrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+    [Paginator.GetTransitGatewayRegistrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
     """
 
     def paginate(
@@ -158,7 +158,7 @@ class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         TransitGatewayArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[GetTransitGatewayRegistrationsResponseTypeDef, None, None]:
+    ) -> Iterator[GetTransitGatewayRegistrationsResponseTypeDef]:
         """
-        [GetTransitGatewayRegistrations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations.paginate)
+        [GetTransitGatewayRegistrations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations.paginate)
         """
